# swpclib



A library to interact with NOAA's Space Weather API

- Free software: MIT license
- Documentation: https://swpclib.readthedocs.io.


## Features

- TODO

## Credits

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.
